--[[
Copyright 2013 João Cardoso
PetTracker Broker is distributed under the terms of the GNU General Public License (Version 3).
As a special exception, the copyright holders of this addon do not give permission to
redistribute and/or modify it.

This addon is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the addon. If not, see <http://www.gnu.org/licenses/gpl-3.0.txt>.

This file is part of PetTracker Broker.
--]]

local ADDON = ...
local Drop = CreateFrame('Frame', ADDON .. 'Drop', nil, 'UIDropDownMenuTemplate')
local Tooltip = CreateFrame('Frame', ADDON .. 'Tip', UIParent, 'GameTooltipTemplate')
Tooltip:RegisterEvent('PET_JOURNAL_LIST_UPDATE')
Tooltip:RegisterEvent('ZONE_CHANGED_NEW_AREA')
Tooltip:RegisterEvent('WORLD_MAP_UPDATE')
Tooltip:SetSize(230, 1)

local Tracker = PetTracker.ZoneTracker(Tooltip)
local Anchor = CreateFrame('Frame', '$parentAnchor', Tooltip)
Anchor:SetPoint('TOPLEFT', 10, -7)
Anchor:SetSize(1, 1)

local Broker = LibStub:GetLibrary('LibDataBroker-1.1'):NewDataObject('PetTracker', {
	type = 'data source',
	icon = 'Interface/Icons/Tracking_WildPet',
	tooltip = Tooltip,
	label = PETS,

	OnClick = function(self, button)
		if button == 'RightButton' then
			ToggleDropDownMenu(1, nil, Drop, self, 0, 0)
		else
			PetTracker_NoTracking = not PetTracker_NoTracking
			WatchFrame_Update()
		end
	end
})

Tooltip:SetScript('OnShow', function(self)
	Tracker:Reset()
	Tracker:SetWidth(self:GetWidth() - 20)
	Tracker:DisplayAt(Anchor)

	self:SetHeight(self:GetTop() - Tracker:Last():GetBottom() + 14)
end)

Tooltip:SetScript('OnEvent', function()
	local progress = PetTracker.Journal:GetCurrentProgress()
	local owned = 0

	for i = PetTracker.MaxQuality, 1, -1 do
		owned = owned + #progress[i]
	end

	Broker.text = owned .. '/' .. progress.total
end)

UIDropDownMenu_Initialize(Drop, function()
	UIDropDownMenu_AddButton {
		text = 'Track Pets',
		checked = not PetTracker_NoTracking,
		isNotRadio = true,
		func = function()
			PetTracker_NoTracking = not PetTracker_NoTracking
			WatchFrame_Update()
		end
	}

	UIDropDownMenu_AddButton {
		text = 'Captured Pets',
		checked = PetTracker_CapturedPets,
		isNotRadio = true,
		func = function()
			PetTracker_CapturedPets = not PetTracker_CapturedPets
			WatchFrame_Update()
		end
	}
end, 'MENU')